(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     41509,       1407]*)
(*NotebookOutlinePosition[     55073,       1799]*)
(*  CellTagsIndexPosition[     54259,       1765]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Unit` Guide", "Chapter",
  CellTags->"c:1"],

Cell["\[Copyright] Yuri E. Kandrashkin, 2007", "Text",
  TextAlignment->Right],

Cell[CellGroupData[{

Cell["Summary", "Section",
  CellTags->{"Unit`", "i:1", "b:0.0", "c:2"}],

Cell[TextData[{
  "The package ",
  StyleBox["Unit`", "MR"],
  " grants an elegant method to work with units. It uses the definition of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " standard packages ",
  StyleBox["Miscellaneous`Units`", "MR"],
  " , ",
  StyleBox["Miscellaneous`SIUnits`", "MR"],
  ", and ",
  StyleBox["Miscellaneous`PhysicalConstants`", "MR"],
  " and expands its definitions to give:\n1. Compact typing and reading of \
units ",
  StyleBox["5\[SmallCircle]kg", "MR"],
  "\n2. Unit transformation rules ",
  Cell[BoxData[
      \(\(\((2\[SmallCircle]kg)\)\^2\) 
        3\[SmallCircle]m\[LongRightArrow]12\[SmallCircle]kg\^2\ m\)], "MR"],
  "\n3. Subscripts might be used as symbols ",
  Cell[BoxData[
      \(TraditionalForm\`1\[SmallCircle]N\_A\)]],
  " \n4. Work with fundamental constants as with units\n5. Evaluation \
protection of units, so unit m in expression ",
  StyleBox["m=1; length=1\[SmallCircle]m", "MR"],
  " is treated correctly\n6. The results are presented in globally defined \
format which can be easily changed\n7. The ability of incorporation a set of \
notation for units of specific field of research"
}], "Text",
  CellTags->"b:0.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  CellTags->{"Unit: Introduction", "i:2", "b:0.1", "c:3"}],

Cell[TextData[{
  "The package ",
  StyleBox["Unit`", "MR"],
  " allows to use acronym form of fundamental units with no harm even if the \
corresponding symbols have values. Some other properties of the package will \
be described below."
}], "Text",
  CellTags->"b:0.1"],

Cell["This loads a package", "Text",
  CellTags->"b:0.1"],

Cell[BoxData[
    \(<< \ Unit`\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->"b:0.1"],

Cell[TextData[{
  "The input and output of units is designed as arguments of function ",
  StyleBox["Unit", "MR"],
  ": "
}], "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Unit[Meter]\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->"b:0.1"],

Cell[BoxData[
    \(1\[SmallCircle]Meter\)], "Output",
  CellLabel->"Out[2]=",
  CellTags->"b:0.1"]
}, Open  ]],

Cell["Although the output looks as a function it is not:", "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // FullForm\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->"b:0.1"],

Cell[BoxData[
    TagBox[
      StyleBox[\(Unit[Meter]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[3]//FullForm=",
  CellTags->"b:0.1"]
}, Open  ]],

Cell[TextData[{
  "The convenient input of symbol ",
  StyleBox["\[SmallCircle]", "MR"],
  " is typing ",
  StyleBox["\[AliasIndicator]sc\[AliasIndicator]", "MR"],
  ". Thus the next example can be entered as ",
  StyleBox["5\[AliasIndicator]sc\[AliasIndicator]m", "MR"]
}], "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(5\[SmallCircle]m\)], "Input",
  CellLabel->"In[4]:=",
  CellTags->"b:0.1"],

Cell[BoxData[
    \(5\[SmallCircle]m\)], "Output",
  CellLabel->"Out[4]=",
  CellTags->"b:0.1"]
}, Open  ]],

Cell[TextData[{
  "This expression is not a function ",
  StyleBox["Unit", "MR"],
  " anymore but a product:"
}], "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // InputForm\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->"b:0.1"],

Cell["5*Unit[m]", "Output",
  CellLabel->"Out[5]//InputForm=",
  CellTags->"b:0.1"]
}, Open  ]],

Cell["\<\
Often symbols like m are used as names of variables. By default the \
definition of a symbol acts globally in any expression. \
\>", "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = Array[a, {2, 2}];\)\), "\[IndentingNewLine]", 
    \(m // MatrixForm\)}], "Input",
  CellLabel->"In[6]:=",
  CellTags->"b:0.1"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(a[1, 1]\), \(a[1, 2]\)},
            {\(a[2, 1]\), \(a[2, 2]\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[7]//MatrixForm=",
  CellTags->"b:0.1"]
}, Open  ]],

Cell[TextData[{
  "To prevent this unlikely behavior function ",
  StyleBox["Unit", "MR"],
  " has an attribute ",
  StyleBox["HoldAll", "MR"],
  ". This property allows to use short acronyms in SI notation with no harm:"
}], "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(3\[SmallCircle]\((m\ kg)\)\)], "Input",
  CellLabel->"In[8]:=",
  CellTags->"b:0.1"],

Cell[BoxData[
    \(3\[SmallCircle]\(m\ kg\)\)], "Output",
  CellLabel->"Out[8]=",
  CellTags->"b:0.1"]
}, Open  ]],

Cell[TextData[{
  "This clears the value of ",
  StyleBox["m", "MR"]
}], "Text",
  CellTags->"b:0.1"],

Cell[BoxData[
    \(Clear[m]\)], "Input",
  CellLabel->"In[9]:=",
  CellTags->"b:0.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Product and Power of units", "Section",
  CellTags->{"Unit: Product", "i:3", "b:0.2", "c:4"}],

Cell["\<\
The power of an expression is transformed to product of a value and its unit: \
\
\>", "Text",
  CellTags->"b:0.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((2\[SmallCircle]Length)\)\^2\)], "Input",
  CellLabel->"In[10]:=",
  CellTags->"b:0.2"],

Cell[BoxData[
    \(4\[SmallCircle]Length\^2\)], "Output",
  CellLabel->"Out[10]=",
  CellTags->"b:0.2"]
}, Open  ]],

Cell["\<\
The product of two or more expressions is automatically simplified:\
\>", "Text",
  CellTags->"b:0.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(2\[SmallCircle]Length\ 3\[SmallCircle]Weight\)\)\)], "Input",
  CellLabel->"In[11]:=",
  CellTags->"b:0.2"],

Cell[BoxData[
    \(6\[SmallCircle]\(Length\ Weight\)\)], "Output",
  CellLabel->"Out[11]=",
  CellTags->"b:0.2"]
}, Open  ]],

Cell["The internal form of the expression is", "Text",
  CellTags->"b:0.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // InputForm\)], "Input",
  CellLabel->"In[12]:=",
  CellTags->"b:0.2"],

Cell["6*Unit[Length*Weight]", "Output",
  CellLabel->"Out[12]//InputForm=",
  CellTags->"b:0.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transformation to unitless form", "Section",
  CellTags->{"Unit: Remove", "i:4", "b:0.3", "c:5"}],

Cell[TextData[{
  "If there is necessity of removing the head of function ",
  StyleBox["Unit", "MR"],
  " one might use the function ",
  StyleBox["ReplaceAll", "MR"],
  ":"
}], "Text",
  CellTags->"b:0.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(5\[SmallCircle]Meter /. Unit[a_] \[RuleDelayed] a\)], "Input",
  CellLabel->"In[13]:=",
  CellTags->"b:0.3"],

Cell[BoxData[
    \(5\ Meter\)], "Output",
  CellLabel->"Out[13]=",
  CellTags->"b:0.3"]
}, Open  ]],

Cell[TextData[{
  "The result doesn't contain a function ",
  StyleBox["Unit", "MR"]
}], "Text",
  CellTags->"b:0.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // InputForm\)], "Input",
  CellLabel->"In[14]:=",
  CellTags->"b:0.3"],

Cell["5*Meter", "Output",
  CellLabel->"Out[14]//InputForm=",
  CellTags->"b:0.3"]
}, Open  ]],

Cell["The simple way to remove units is using the following form:", "Text",
  CellTags->"b:0.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \({{1\[SmallCircle]Meter, 
          3\[SmallCircle]Kilogram}, {3\[SmallCircle]Meter, 
          5\[SmallCircle]Kilogram}, {5\[SmallCircle]Meter, 
          1\[SmallCircle]Kilogram}} /. _Unit \[RuleDelayed] 1\)], "Input",
  CellLabel->"In[15]:=",
  CellTags->"b:0.3"],

Cell[BoxData[
    \({{1, 3}, {3, 5}, {5, 1}}\)], "Output",
  CellLabel->"Out[15]=",
  CellTags->"b:0.3"]
}, Open  ]],

Cell["The resulting table now can be displayed in a graphic", "Text",
  CellTags->"b:0.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[%, PlotStyle \[Rule] {PointSize[0.02]}]\)], "Input",
  CellLabel->"In[16]:=",
  CellTags->"b:0.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 -0.132436 0.147151 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .16187 -6 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .45617 -6 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(2)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(3)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(4)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16187 m
.03006 .16187 L
s
[(2)] .01131 .16187 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(3)] .01131 .30902 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(4)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(5)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.02 w
.02381 .30902 Mdot
.5 .60332 Mdot
.97619 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[16]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00CP3oool4000003d0oooo0P0000100?ooo`<00000?@3oool2000000d0oooo001>0?ooo`03
0000003oool0oooo03d0oooo00@000000?ooo`3oool00000@03oool00`000000oooo0?ooo`0k0?oo
o`040000003oool0oooo000000`0oooo001?0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool0?03oool5000003l0oooo00<000000?ooo`3oool02P3oool00500oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0k0?ooo`040000003oool0oooo000003h0oooo0P00000=0?oo
o`00CP3oool010000000oooo0?ooo`00000l0?ooo`040000003oool0oooo000003h0oooo00<00000
0?ooo`000000?P3oool00`000000oooo0?ooo`0<0?ooo`00C`3oool2000003h0oooo0P0000100?oo
o`800000?P3oool3000000`0oooo003o0?ooob40oooo000?0?ooo`030000003oool0oooo0?l0oooo
3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o
0?ooo`<00000303oool000l0oooo00<000000?ooo`3oool0oP3oool5000000/0oooo00090?ooool0
00004@0000070?ooo`003`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo
1@00000;0?ooo`003`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0m0?ooo`<00000303oool000l0oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`03
0000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3o
ool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`800000o`3oool@0?ooo`003`3oool00`00
0000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo
00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?
0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?oo
o`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`800000o`3oool@0?ooo`003`3o
ool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool0
00l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0
oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3o
ool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`800000o`3oool@0?oo
o`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo
3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o
0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3o
ool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`800000o`3o
ool@0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo
0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo
0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000L0oooo10000004
0?ooo`030000003oool0oooo0?l0oooo3`3oool000L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3o0?ooo`l0oooo00080?ooo`030000003oool0oooo00@0oooo0`00003o0?ooo`l0
oooo00090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool?0?ooo`001`3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo3`3oool000P0oooo0P00
00050?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?
0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0
oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool200000?l0oooo403o
ool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?oo
o`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0
o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0
oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool200000?l0
oooo403oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?oo
o`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?oo
o`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000
003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool2
00000?l0oooo403oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000
oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<0
00000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?oo
o`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`00
3`3oool200000?l0oooo403oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool0
0`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0
oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo
00080?ooo`800000103oool300000?l0oooo403oool000L0oooo00@000000?ooo`3oool000000P3o
ool500000?l0oooo3`3oool000T0oooo00@000000?ooo`3oool0oooo1@00003o0?ooo`l0oooo000:
0?ooo`030000003oool0oooo00D00000o`3oool?0?ooo`001`3oool010000000oooo0?ooo`000003
0?ooo`<00000o`3oool@0?ooo`00203oool2000000D0oooo00<000000?ooo`3oool0o`3oool?0?oo
o`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo
3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o
0?ooo`l0oooo000?0?ooo`800000o`3oool@0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0
oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3o
ool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo
0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo
0?ooo`3o0?ooo`l0oooo000?0?ooo`800000o`3oool@0?ooo`003`3oool00`000000oooo0?ooo`3o
0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3o
ool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003o
ool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`00
0000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`800000o`3oool@0?ooo`003`3oool00`000000oooo
0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`03
0000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3o
ool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`800000o`3oool@0?ooo`003`3oool00`00
0000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo
00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?
0?ooo`030000003oool0oooo0?l0oooo3`3oool000T0oooo0`0000030?ooo`030000003oool0oooo
0?l0oooo3`3oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`l0
oooo00070?ooo`D000000`3oool300000?l0oooo3`3oool000L0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`3o0?ooo`l0oooo00080?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool0o`3oool?0?ooo`002@3oool2000000@0oooo00<000000?ooo`3oool0o`3oool?
0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0
oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?oo
o`3o0?ooo`l0oooo000?0?ooo`800000o`3oool@0?ooo`003`3oool00`000000oooo0?ooo`3o0?oo
o`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0
o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0
oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000
oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`800000o`3oool@0?ooo`003`3oool00`000000oooo0?oo
o`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?oo
o`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000
003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool0
0`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`800000o`3oool@0?ooo`003`3oool00`000000
oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<0
00000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?oo
o`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`00
3`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`800000o`3oool@0?ooo`003`3oool0
0`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0
oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo
000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000P0oooo0P0000050?ooo`030000003oool0
oooo07d0oooo0`00002>0?ooo`001`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo07`0oooo1@00002=0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`<00000O03oool50000
08d0oooo00080?ooo`8000001@3oool00`000000oooo0?ooo`1l0?ooo`D00000S@3oool000P0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1m0?ooo`<00000SP3oool000P0oooo0`00
00040?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.760744, 0.690121, \
0.0154472, 0.024994}},
  CellTags->"b:0.3"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[16]=",
  CellTags->"b:0.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conversion between different systems of units ", "Section",
  CellTags->{"$UnitFormat", "i:5", "b:0.4", "c:6"}],

Cell[TextData[{
  "Global variable ",
  StyleBox["$UnitFormat", "MR"],
  " determines the output system of units. By default it is set as ",
  StyleBox["\"SI\"", "MR"],
  ":"
}], "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \($UnitFormat\)], "Input",
  CellLabel->"In[53]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    \("Energy in cm"\)], "Output",
  CellLabel->"Out[53]=",
  CellTags->"b:0.4"]
}, Open  ]],

Cell[TextData[{
  "Other values include ",
  StyleBox["\"MKS\"", "MR"],
  ", ",
  StyleBox["\"CGS\"", "MR"],
  ", ",
  StyleBox["\"SIAcronym\"", "MR"],
  ", ",
  StyleBox["\"SIFundamental\"", "MR"],
  ", and ",
  StyleBox["\"SIConstants\"", "MR"],
  ". "
}], "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Part[#, 1, 1, 1] &\) /@ DownValues[UnitFormat]\)], "Input",
  CellLabel->"In[54]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    \({"CGS", "Energy in cm", "MKS", "SI", "SIAcronym", "SIConstants", 
      "SIFundamental"}\)], "Output",
  CellLabel->"Out[54]=",
  CellTags->"b:0.4"]
}, Open  ]],

Cell[TextData[{
  "With the values ",
  StyleBox["\"SI\"", "MR"],
  ", ",
  StyleBox["\"MKS\"", "MR"],
  ", ",
  StyleBox["\"CGS\"", "MR"],
  " the output is similar to using the corresponding functions from the \
package ",
  StyleBox["Miscellaneous`Units`", "MR"]
}], "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((3\[SmallCircle]Meter)\)\^2\)], "Input",
  CellLabel->"In[55]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    \(9\[SmallCircle]Meter\^2\)], "Output",
  CellLabel->"Out[55]=",
  CellTags->"b:0.4"]
}, Open  ]],

Cell[TextData[{
  "The values ",
  StyleBox["\"SIAcronym\",", "MR"],
  " ",
  StyleBox["\"SIFundamental\"", "MR"],
  " and ",
  StyleBox["\"SIConstants\"", "MR"],
  " give a compact form of SI system of units:"
}], "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\($UnitFormat = "\<SIAcronym\>";\)\), "\[IndentingNewLine]", 
    \(\((3\[SmallCircle]m)\)\^2\)}], "Input",
  CellLabel->"In[56]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    \(9\[SmallCircle]m\^2\)], "Output",
  CellLabel->"Out[57]=",
  CellTags->"b:0.4"]
}, Open  ]],

Cell[TextData[{
  StyleBox["\"SIAcronym\"", "MR"],
  " sets the rules for acronyms of SI system of units, ",
  StyleBox["\"SIConstants\"", "MR"],
  " adds additional transformations for physical constants, and ",
  StyleBox["\"SIFundamental\"", "MR"],
  " can be used to convert all values in unique representation of fundamental \
SI units. "
}], "Text",
  CellTags->"b:0.4"],

Cell[TextData[{
  "If there is no action on ",
  StyleBox["Unit", "MR"],
  " its argument is not evaluated:  "
}], "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(expr = 2\[SmallCircle]Meter\ a\)], "Input",
  CellLabel->"In[79]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    \(\(2\ a\)\[SmallCircle]Meter\)], "Output",
  CellLabel->"Out[79]=",
  CellTags->"b:0.4"]
}, Open  ]],

Cell[TextData[{
  "The function ",
  StyleBox["UnitUpdate", "MR"],
  " forces recomputation of function ",
  StyleBox["Unit", "MR"]
}], "Text",
  CellTags->{"UnitUpdate", "i:6", "b:0.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(expr // UnitUpdate\)], "Input",
  CellLabel->"In[80]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    \(\(200\ a\)\[SmallCircle]Centimeter\)], "Output",
  CellLabel->"Out[80]=",
  CellTags->"b:0.4"]
}, Open  ]],

Cell["This reevaluates expr in the CGS system of units:", "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\($UnitFormat = "\<CGS\>";\)\), "\[IndentingNewLine]", 
    \(expr // UnitUpdate\)}], "Input",
  CellLabel->"In[81]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    \(\(200\ a\)\[SmallCircle]Centimeter\)], "Output",
  CellLabel->"Out[82]=",
  CellTags->"b:0.4"]
}, Open  ]],

Cell[TextData[{
  "But acronyms like ",
  StyleBox["m", "MR"],
  " for ",
  StyleBox["Meter", "MR"],
  " are unknown while ",
  StyleBox["$UnitFormat", "MR"],
  " has the value ",
  StyleBox["\"CGS\"", "MR"],
  ":"
}], "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(expr = 0.5\[SmallCircle]m;\)\), "\[IndentingNewLine]", 
    \(expr // UnitUpdate\)}], "Input",
  CellLabel->"In[83]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    \(0.5`\[SmallCircle]m\)], "Output",
  CellLabel->"Out[84]=",
  CellTags->"b:0.4"]
}, Open  ]],

Cell["\<\
To add extra conversion rules one can list their names after the output \
format: \
\>", "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\($UnitFormat = {"\<CGS\>", "\<SIAcronym\>"};\)\), \
"\[IndentingNewLine]", 
    \(expr // UnitUpdate\)}], "Input",
  CellLabel->"In[85]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    \(50.`\[SmallCircle]Centimeter\)], "Output",
  CellLabel->"Out[86]=",
  CellTags->"b:0.4"]
}, Open  ]],

Cell[TextData[{
  "The value ",
  StyleBox["All", "MR"],
  " can be used to apply all transformation rules: ",
  StyleBox["$UnitFormat={\"CGS\",All}", "MR"],
  ". The second argument is used here to convert the expression in the \
specific format."
}], "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(UnitUpdate[expr, {"\<SI\>", All}]\)], "Input",
  CellLabel->"In[87]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    \(0.5`\[SmallCircle]Meter\)], "Output",
  CellLabel->"Out[87]=",
  CellTags->"b:0.4"]
}, Open  ]],

Cell[TextData[{
  "This clears the value of ",
  StyleBox["expr", "MR"],
  " "
}], "Text",
  CellTags->"b:0.4"],

Cell[BoxData[
    \(Clear[expr]\)], "Input",
  CellLabel->"In[78]:=",
  CellTags->"b:0.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Work with constants as with units", "Section",
  CellTags->{"b:0.5", "c:7"}],

Cell["\<\
Often the expressions are presented in simpler form if some fundamental \
constants are treated as units. For example, one can work in units of speed \
of the light:\
\>", "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\($UnitFormat = "\<SI\>";\)\), "\[IndentingNewLine]", 
    \(v = 3\[SmallCircle]c\)}], "Input",
  CellLabel->"In[33]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    \(3\[SmallCircle]c\)], "Output",
  CellLabel->"Out[34]=",
  CellTags->"b:0.5"]
}, Open  ]],

Cell[TextData[{
  "Because of the value of constant ",
  StyleBox["c", "MR"],
  " is undefined the evaluation of ",
  StyleBox["Unit", "MR"],
  " doesn't change the expression"
}], "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(v // UnitUpdate\)], "Input",
  CellLabel->"In[35]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    \(3\[SmallCircle]c\)], "Output",
  CellLabel->"Out[35]=",
  CellTags->"b:0.5"]
}, Open  ]],

Cell[TextData[{
  "But deriving the value of v or computing and comparing it with other \
expressions occasionally needs the conversion to standard system of units. \
The package supports a format ",
  StyleBox["\"SIConstants\"", "MR"],
  " which allows to convert the constants in SI system of units during the \
evaluation of function ",
  StyleBox["Unit", "MR"]
}], "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\($UnitFormat = "\<SIConstants\>";\)\), "\[IndentingNewLine]", 
    \(v\^2\)}], "Input",
  CellLabel->"In[36]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    \(808879660863135876\[SmallCircle]\(m\^2\/s\^2\)\)], "Output",
  CellLabel->"Out[37]=",
  CellTags->"b:0.5"]
}, Open  ]],

Cell[TextData[{
  "Although the value of ",
  StyleBox["v", "MR"],
  " is still given in units of ",
  StyleBox["c", "MR"],
  ":"
}], "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(v\)], "Input",
  CellLabel->"In[38]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    \(3\[SmallCircle]c\)], "Output",
  CellLabel->"Out[38]=",
  CellTags->"b:0.5"]
}, Open  ]],

Cell["\<\
Another example is a definition of electron magnetogyric ratio:\
\>", "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Gamma] = 1\[SmallCircle]\((2  \[Mu]\_e/\[HBar])\)\)], "Input",
  CellLabel->"In[39]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    \(1\[SmallCircle]\(\(2\ \[Mu]\_e\)\/\[HBar]\)\)], "Output",
  CellLabel->"Out[39]=",
  CellTags->"b:0.5"]
}, Open  ]],

Cell["Its value in SI is", "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Gamma] // UnitUpdate\)], "Input",
  CellLabel->"In[40]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    \(\(-1.7608597939698877`*^11\)\[SmallCircle]\(1\/\(s\ T\)\)\)], "Output",
  CellLabel->"Out[40]=",
  CellTags->"b:0.5"]
}, Open  ]],

Cell["\<\
The standard value of magnetic field in electron spin resonance experiments \
is 350 mT and the resonance frequency is  \
\>", "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(B = 0.350\[SmallCircle]T;\)\), "\[IndentingNewLine]", 
    \(\[Omega] = \[Gamma]\ B\)}], "Input",
  CellLabel->"In[41]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    \(\(-6.163009278894607`*^10\)\[SmallCircle]\(1\/s\)\)], "Output",
  CellLabel->"Out[42]=",
  CellTags->"b:0.5"]
}, Open  ]],

Cell[TextData[{
  "This corresponds to wavelength ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(~\)\(3\)\) cm\^\(-1\)\)]]
}], "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Omega]\/\(2  \[Pi]\[SmallCircle]c\)\)], "Input",
  CellLabel->"In[43]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    \(\(-32.71841451919695`\)\[SmallCircle]\(1\/m\)\)], "Output",
  CellLabel->"Out[43]=",
  CellTags->"b:0.5"]
}, Open  ]],

Cell[TextData[{
  "The computation of the next line gives the complete set of notations of \
the format ",
  StyleBox["\"SIConstants\"", "MR"]
}], "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(First[UnitFormat["\<SIConstants\>"]] // ColumnForm\)], "Input",
  CellLabel->"In[44]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(HoldPattern[A] \[Rule] Ampere\)},
          {\(HoldPattern[Bq] \[Rule] Becquerel\)},
          {\(HoldPattern[cd] \[Rule] Candela\)},
          {\(HoldPattern[C] \[Rule] Coulomb\)},
          {\(HoldPattern[F] \[Rule] Farad\)},
          {\(HoldPattern[H] \[Rule] Henry\)},
          {\(HoldPattern[Hz] \[Rule] Hertz\)},
          {\(HoldPattern[J] \[Rule] Joule\)},
          {\(HoldPattern[K] \[Rule] Kelvin\)},
          {\(HoldPattern[kg] \[Rule] Kilogram\)},
          {\(HoldPattern[lm] \[Rule] Lumen\)},
          {\(HoldPattern[lx] \[Rule] Lux\)},
          {\(HoldPattern[m] \[Rule] Meter\)},
          {\(HoldPattern[mol] \[Rule] Mole\)},
          {\(HoldPattern[N] \[Rule] Newton\)},
          {\(HoldPattern[\[CapitalOmega]] \[Rule] Ohm\)},
          {\(HoldPattern[Pa] \[Rule] Pascal\)},
          {\(HoldPattern[rad] \[Rule] Radian\)},
          {\(HoldPattern[s] \[Rule] Second\)},
          {\(HoldPattern[S] \[Rule] Siemens\)},
          {\(HoldPattern[T] \[Rule] Tesla\)},
          {\(HoldPattern[V] \[Rule] Volt\)},
          {\(HoldPattern[W] \[Rule] Watt\)},
          {\(HoldPattern[Wb] \[Rule] Weber\)},
          {\(HoldPattern[c] \[Rule] \(299792458\ Meter\)\/Second\)},
          {\(HoldPattern[\[Mu]\_0] \[Rule] \(\[Pi]\ Second\ Volt\)\/\(2500000\
\ Ampere\ Meter\)\)},
          {\(HoldPattern[\[CurlyEpsilon]\_0] \[Rule] \(8.854187817`*^-12\ \
Ampere\ Second\)\/\(Meter\ Volt\)\)},
          {\(HoldPattern[\[HBar]] \[Rule] 
              1.0545715964207855`*^-34\ Joule\ Second\)},
          {\(HoldPattern[e] \[Rule] 1.602176462`*^-19\ Coulomb\)},
          {\(HoldPattern[m\_e] \[Rule] 9.10938188`*^-31\ Kilogram\)},
          {\(HoldPattern[m\_p] \[Rule] 1.67262158`*^-27\ Kilogram\)},
          {\(HoldPattern[m\_n] \[Rule] 1.67492716`*^-27\ Kilogram\)},
          {\(HoldPattern[N\_A] \[Rule] 6.02214199`*^23\/Mole\)},
          {\(HoldPattern[k] \[Rule] \(1.3806503`*^-23\ Joule\)\/Kelvin\)},
          {\(HoldPattern[F] \[Rule] \(96485.3415`\ Coulomb\)\/Mole\)},
          {\(HoldPattern[
                R] \[Rule] \(8.314472`\ Joule\)\/\(Kelvin\ Mole\)\)},
          {\(HoldPattern[\[Alpha]] \[Rule] 0.007297352533`\)},
          {\(HoldPattern[a\_0] \[Rule] 5.291772083`*^-11\ Meter\)},
          {\(HoldPattern[R\_\[Infinity]] \[Rule] 
              1.0973731568549`*^7\/Meter\)},
          {\(HoldPattern[\[Lambda]\_c] \[Rule] 2.426310215`*^-12\ Meter\)},
          {\(HoldPattern[\[Mu]\_B] \[Rule] \(9.274008991700905`*^-24\ Coulomb\
\ Joule\ Second\)\/Kilogram\)},
          {\(HoldPattern[\[Mu]\_e] \[Rule] \(-\(\(9.28476362`*^-24\ \
Joule\)\/Tesla\)\)\)},
          {\(HoldPattern[g\_e] \[Rule] \(-2.0023193043737`\)\)},
          {\(HoldPattern[\[Mu]\_p] \[Rule] \(1.410606633`*^-26\ \
Joule\)\/Tesla\)},
          {\(HoldPattern[
                G] \[Rule] \(6.673`*^-11\ Meter\^2\ Newton\)\/Kilogram\^2\)},
          {\(HoldPattern[g\_n] \[Rule] \(9.80665`\ Meter\)\/Second\^2\)}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {HoldPattern[ A] -> Ampere, HoldPattern[ Bq] -> Becquerel, 
        HoldPattern[ cd] -> Candela, HoldPattern[ C] -> Coulomb, HoldPattern[ 
        F] -> Farad, HoldPattern[ H] -> Henry, HoldPattern[ Hz] -> Hertz, 
        HoldPattern[ J] -> Joule, HoldPattern[ K] -> Kelvin, HoldPattern[ kg] -> 
        Kilogram, HoldPattern[ lm] -> Lumen, HoldPattern[ lx] -> Lux, 
        HoldPattern[ m] -> Meter, HoldPattern[ mol] -> Mole, HoldPattern[ N] -> 
        Newton, HoldPattern[ \[CapitalOmega]] -> Ohm, HoldPattern[ Pa] -> 
        Pascal, HoldPattern[ rad] -> Radian, HoldPattern[ s] -> Second, 
        HoldPattern[ S] -> Siemens, HoldPattern[ T] -> Tesla, HoldPattern[ V] -> 
        Volt, HoldPattern[ W] -> Watt, HoldPattern[ Wb] -> Weber, HoldPattern[
         c] -> Times[ 299792458, Meter, 
          Power[ Second, -1]], HoldPattern[ 
          Subscript[ \[Mu], 0]] -> Times[ 
          Rational[ 1, 2500000], 
          Power[ Ampere, -1], 
          Power[ Meter, -1], Pi, Second, Volt], HoldPattern[ 
          Subscript[ \[CurlyEpsilon], 0]] -> 
        Times[ .88541878170000005*^-11, Ampere, 
          Power[ Meter, -1], Second, 
          Power[ Volt, -1]], HoldPattern[ \[HBar]] -> 
        Times[ .10545715964207855*^-33, Joule, Second], HoldPattern[ e] -> 
        Times[ .16021764620000001*^-18, Coulomb], HoldPattern[ 
          Subscript[ m, e]] -> Times[ .91093818800000006*^-30, Kilogram], 
        HoldPattern[ 
          Subscript[ m, p]] -> Times[ .167262158*^-26, Kilogram], HoldPattern[
         
          Subscript[ m, n]] -> Times[ .16749271600000001*^-26, Kilogram], 
        HoldPattern[ 
          Subscript[ N, A]] -> Times[ .602214199*^24, 
          Power[ Mole, -1]], HoldPattern[ k] -> 
        Times[ .13806503000000001*^-22, Joule, 
          Power[ Kelvin, -1]], HoldPattern[ F] -> Times[ 
        96485.341499999995, Coulomb, 
          Power[ Mole, -1]], HoldPattern[ R] -> Times[ 
        8.3144720000000003, Joule, 
          Power[ Kelvin, -1], 
          Power[ Mole, -1]], HoldPattern[ \[Alpha]] -> .007297352533, 
        HoldPattern[ 
          Subscript[ a, 0]] -> Times[ .52917720829999998*^-10, Meter], 
        HoldPattern[ 
          Subscript[ R, Infinity]] -> Times[ 10973731.568549, 
          Power[ Meter, -1]], HoldPattern[ 
          Subscript[ \[Lambda], c]] -> Times[ .2426310215*^-11, Meter], 
        HoldPattern[ 
          Subscript[ \[Mu], B]] -> 
        Times[ .92740089917009053*^-23, Coulomb, Joule, 
          Power[ Kilogram, -1], Second], HoldPattern[ 
          Subscript[ \[Mu], e]] -> Times[ -.92847636200000004*^-23, Joule, 
          Power[ Tesla, -1]], HoldPattern[ 
          Subscript[ g, e]] -> -2.0023193043737, HoldPattern[ 
          Subscript[ \[Mu], p]] -> Times[ .14106066330000001*^-25, Joule, 
          Power[ Tesla, -1]], HoldPattern[ G] -> 
        Times[ .66729999999999999*^-10, 
          Power[ Kilogram, -2], 
          Power[ Meter, 2], Newton], HoldPattern[ 
          Subscript[ g, n]] -> Times[ 9.8066499999999994, Meter, 
          Power[ Second, -2]]}],
      Editable->False]], "Output",
  CellLabel->"Out[44]=",
  CellTags->"b:0.5"]
}, Open  ]],

Cell["This clears the used values ", "Text",
  CellTags->"b:0.5"],

Cell[BoxData[
    \(Clear[v, \[Gamma], B, \[Omega]]\)], "Input",
  CellLabel->"In[45]:=",
  CellTags->"b:0.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of a new system of units", "Section",
  CellTags->{"UnitFormat", "i:7", "b:0.6", "c:8"}],

Cell[TextData[{
  "In many areas of research there are special conventions on the units. For \
instance wavenumber, ",
  Cell[BoxData[
      \(TraditionalForm\`cm\^\(-1\)\)]],
  ", is used to define an energy or frequency in spectroscopy. In molecular \
and chemical physics the energy is often is defined in units of temperature. \
In such cases it is convenient to set a new system of units supporting the \
traditional notations. A function ",
  StyleBox["UnitFormat", "MR"],
  " can be used to set of new rules of definitions. "
}], "Text",
  CellTags->"b:0.6"],

Cell[TextData[{
  "Every time during the transformation of the value of ",
  StyleBox["Unit", "MR"],
  " the value of ",
  StyleBox["$UnitFormat", "MR"],
  " is checked. The possible value of ",
  StyleBox["$UnitFormat", "MR"],
  " should match to one of arguments of function ",
  StyleBox["UnitFormat", "MR"],
  ":"
}], "Text",
  CellTags->"b:0.6"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Part[#, 1, 1, 1] &\) /@ DownValues[UnitFormat]\)], "Input",
  CellLabel->"In[46]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    \({"CGS", "MKS", "SI", "SIAcronym", "SIConstants", 
      "SIFundamental"}\)], "Output",
  CellLabel->"Out[46]=",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[TextData[{
  "Except the cases of ",
  StyleBox["\"SI\"", "MR"],
  ", ",
  StyleBox["\"CGS\"", "MR"],
  " and ",
  StyleBox["\"MKS\"", "MR"],
  " all other definitions of function ",
  StyleBox["UnitFormat", "MR"],
  " must be sets of rules of transformations to SI system of units and from \
SI to a new system of units."
}], "Text",
  CellTags->"b:0.6"],

Cell["Let's define a new system of energy units: ", "Text",
  CellTags->"b:0.6"],

Cell[BoxData[{
    \(\(Unprotect[UnitFormat];\)\), "\[IndentingNewLine]", 
    \(UnitFormat["\<Energy in cm\>"] := {{HoldPattern[
              cm] \[RuleDelayed] \((1.98644544\ \(10\^\(-23\)\) \
Joule)\)\^\(-1\), 
          HoldPattern[kT] \[RuleDelayed] 1.3806503\ 10\^\(-23\)\ Joule, 
          HoldPattern[eV] \[RuleDelayed] 
            1.602176462\ 10\^\(-19\)\ Joule}, {Joule \[RuleDelayed] 
            5.03411762\ \(10\^22\) cm\^\(-1\)}}\), "\[IndentingNewLine]", 
    \(\(Protect[UnitFormat];\)\)}], "Input",
  CellLabel->"In[47]:=",
  CellTags->"b:0.6"],

Cell[TextData[{
  "The functions ",
  StyleBox["HoldPattern", "MR"],
  " and ",
  StyleBox["RuleDelayed", "MR"],
  " (",
  StyleBox["\[RuleDelayed]", "MR"],
  ") in the definition above used to prevent evaluation of symbols ",
  StyleBox["cm", "MR"],
  ", ",
  StyleBox["kT", "MR"],
  " and e",
  StyleBox["V", "MR"],
  " even if they have values:"
}], "Text",
  CellTags->"b:0.6"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cm = 0.01\ Meter;\)\), "\[IndentingNewLine]", 
    \(\($UnitFormat = "\<Energy in cm\>";\)\), "\[IndentingNewLine]", 
    \(0.1\[SmallCircle]\ eV // UnitUpdate\)}], "Input",
  CellLabel->"In[50]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    \(806.5544757703461`\[SmallCircle]\(1\/cm\)\)], "Output",
  CellLabel->"Out[52]=",
  CellTags->"b:0.6"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 781}},
ShowPageBreaks->False,
WindowSize->{726, 740},
WindowMargins->{{200, Automatic}, {0, Automatic}},
PrintingStartingPageNumber->1,
ShowSelection->True,
TaggingRules:>{"NextIndexingNumber" -> 8, "IndexEntries" -> {{"i:1", \
"Unit`"}, {"i:5", "$UnitFormat"}, {"i:6", "UnitUpdate"}, {"i:7", \
"UnitFormat"}, {"i:2", "Unit", "Introduction"}, {"i:3", "Unit", "Product"}, \
{"i:4", "Unit", "Remove"}}, "PaginationCache" -> {{2007, 4, 10, 13, 10, \
19.671875`9.046420693460865}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, \
1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, \
2, 2, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, \
4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, \
5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 7, 7, 7, \
7, 7, 7, 7, 7, 7, 7, 7}, Automatic}},
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1776, 53, 49, 1, 92, "Chapter",
      CellTags->"c:1"]},
  "Unit`"->{
    Cell[1931, 61, 72, 1, 65, "Section",
      CellTags->{"Unit`", "i:1", "b:0.0", "c:2"}]},
  "i:1"->{
    Cell[1931, 61, 72, 1, 65, "Section",
      CellTags->{"Unit`", "i:1", "b:0.0", "c:2"}]},
  "b:0.0"->{
    Cell[1931, 61, 72, 1, 65, "Section",
      CellTags->{"Unit`", "i:1", "b:0.0", "c:2"}],
    Cell[2006, 64, 1193, 29, 234, "Text",
      CellTags->"b:0.0"]},
  "c:2"->{
    Cell[1931, 61, 72, 1, 65, "Section",
      CellTags->{"Unit`", "i:1", "b:0.0", "c:2"}]},
  "Unit: Introduction"->{
    Cell[3236, 98, 90, 1, 65, "Section",
      CellTags->{"Unit: Introduction", "i:2", "b:0.1", "c:3"}]},
  "i:2"->{
    Cell[3236, 98, 90, 1, 65, "Section",
      CellTags->{"Unit: Introduction", "i:2", "b:0.1", "c:3"}]},
  "b:0.1"->{
    Cell[3236, 98, 90, 1, 65, "Section",
      CellTags->{"Unit: Introduction", "i:2", "b:0.1", "c:3"}],
    Cell[3329, 101, 272, 7, 42, "Text",
      CellTags->"b:0.1"],
    Cell[3604, 110, 57, 1, 25, "Text",
      CellTags->"b:0.1"],
    Cell[3664, 113, 88, 3, 29, "Input",
      CellTags->"b:0.1"],
    Cell[3755, 118, 154, 5, 25, "Text",
      CellTags->"b:0.1"],
    Cell[3934, 127, 89, 3, 29, "Input",
      CellTags->"b:0.1"],
    Cell[4026, 132, 99, 3, 27, "Output",
      CellTags->"b:0.1"],
    Cell[4140, 138, 87, 1, 25, "Text",
      CellTags->"b:0.1"],
    Cell[4252, 143, 91, 3, 29, "Input",
      CellTags->"b:0.1"],
    Cell[4346, 148, 242, 8, 41, "Output",
      CellTags->"b:0.1"],
    Cell[4603, 159, 303, 8, 25, "Text",
      CellTags->"b:0.1"],
    Cell[4931, 171, 94, 3, 29, "Input",
      CellTags->"b:0.1"],
    Cell[5028, 176, 95, 3, 27, "Output",
      CellTags->"b:0.1"],
    Cell[5138, 182, 142, 5, 25, "Text",
      CellTags->"b:0.1"],
    Cell[5305, 191, 92, 3, 29, "Input",
      CellTags->"b:0.1"],
    Cell[5400, 196, 83, 2, 43, "Output",
      CellTags->"b:0.1"],
    Cell[5498, 201, 171, 4, 25, "Text",
      CellTags->"b:0.1"],
    Cell[5694, 209, 154, 4, 49, "Input",
      CellTags->"b:0.1"],
    Cell[5851, 215, 407, 12, 53, "Output",
      CellTags->"b:0.1"],
    Cell[6273, 230, 254, 7, 42, "Text",
      CellTags->"b:0.1"],
    Cell[6552, 241, 104, 3, 29, "Input",
      CellTags->"b:0.1"],
    Cell[6659, 246, 103, 3, 27, "Output",
      CellTags->"b:0.1"],
    Cell[6777, 252, 101, 4, 25, "Text",
      CellTags->"b:0.1"],
    Cell[6881, 258, 86, 3, 29, "Input",
      CellTags->"b:0.1"]},
  "c:3"->{
    Cell[3236, 98, 90, 1, 65, "Section",
      CellTags->{"Unit: Introduction", "i:2", "b:0.1", "c:3"}]},
  "Unit: Product"->{
    Cell[7004, 266, 99, 1, 65, "Section",
      CellTags->{"Unit: Product", "i:3", "b:0.2", "c:4"}]},
  "i:3"->{
    Cell[7004, 266, 99, 1, 65, "Section",
      CellTags->{"Unit: Product", "i:3", "b:0.2", "c:4"}]},
  "b:0.2"->{
    Cell[7004, 266, 99, 1, 65, "Section",
      CellTags->{"Unit: Product", "i:3", "b:0.2", "c:4"}],
    Cell[7106, 269, 125, 4, 25, "Text",
      CellTags->"b:0.2"],
    Cell[7256, 277, 109, 3, 29, "Input",
      CellTags->"b:0.2"],
    Cell[7368, 282, 104, 3, 27, "Output",
      CellTags->"b:0.2"],
    Cell[7487, 288, 112, 3, 25, "Text",
      CellTags->"b:0.2"],
    Cell[7624, 295, 137, 3, 29, "Input",
      CellTags->"b:0.2"],
    Cell[7764, 300, 113, 3, 27, "Output",
      CellTags->"b:0.2"],
    Cell[7892, 306, 75, 1, 25, "Text",
      CellTags->"b:0.2"],
    Cell[7992, 311, 93, 3, 29, "Input",
      CellTags->"b:0.2"],
    Cell[8088, 316, 96, 2, 43, "Output",
      CellTags->"b:0.2"]},
  "c:4"->{
    Cell[7004, 266, 99, 1, 65, "Section",
      CellTags->{"Unit: Product", "i:3", "b:0.2", "c:4"}]},
  "Unit: Remove"->{
    Cell[8233, 324, 103, 1, 65, "Section",
      CellTags->{"Unit: Remove", "i:4", "b:0.3", "c:5"}]},
  "i:4"->{
    Cell[8233, 324, 103, 1, 65, "Section",
      CellTags->{"Unit: Remove", "i:4", "b:0.3", "c:5"}]},
  "b:0.3"->{
    Cell[8233, 324, 103, 1, 65, "Section",
      CellTags->{"Unit: Remove", "i:4", "b:0.3", "c:5"}],
    Cell[8339, 327, 207, 7, 25, "Text",
      CellTags->"b:0.3"],
    Cell[8571, 338, 128, 3, 29, "Input",
      CellTags->"b:0.3"],
    Cell[8702, 343, 88, 3, 27, "Output",
      CellTags->"b:0.3"],
    Cell[8805, 349, 117, 4, 25, "Text",
      CellTags->"b:0.3"],
    Cell[8947, 357, 93, 3, 29, "Input",
      CellTags->"b:0.3"],
    Cell[9043, 362, 82, 2, 43, "Output",
      CellTags->"b:0.3"],
    Cell[9140, 367, 96, 1, 25, "Text",
      CellTags->"b:0.3"],
    Cell[9261, 372, 285, 6, 29, "Input",
      CellTags->"b:0.3"],
    Cell[9549, 380, 104, 3, 27, "Output",
      CellTags->"b:0.3"],
    Cell[9668, 386, 90, 1, 25, "Text",
      CellTags->"b:0.3"],
    Cell[9783, 391, 127, 3, 29, "Input",
      CellTags->"b:0.3"],
    Cell[9913, 396, 11860, 316, 184, 2732, 197, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"b:0.3"],
    Cell[21776, 714, 176, 5, 27, "Output",
      CellTags->"b:0.3"]},
  "c:5"->{
    Cell[8233, 324, 103, 1, 65, "Section",
      CellTags->{"Unit: Remove", "i:4", "b:0.3", "c:5"}]},
  "$UnitFormat"->{
    Cell[22001, 725, 117, 1, 65, "Section",
      CellTags->{"$UnitFormat", "i:5", "b:0.4", "c:6"}]},
  "i:5"->{
    Cell[22001, 725, 117, 1, 65, "Section",
      CellTags->{"$UnitFormat", "i:5", "b:0.4", "c:6"}]},
  "b:0.4"->{
    Cell[22001, 725, 117, 1, 65, "Section",
      CellTags->{"$UnitFormat", "i:5", "b:0.4", "c:6"}],
    Cell[22121, 728, 207, 7, 25, "Text",
      CellTags->"b:0.4"],
    Cell[22353, 739, 90, 3, 29, "Input",
      CellTags->"b:0.4"],
    Cell[22446, 744, 94, 3, 27, "Output",
      CellTags->"b:0.4"],
    Cell[22555, 750, 287, 13, 25, "Text",
      CellTags->"b:0.4"],
    Cell[22867, 767, 127, 3, 29, "Input",
      CellTags->"b:0.4"],
    Cell[22997, 772, 168, 4, 27, "Output",
      CellTags->"b:0.4"],
    Cell[23180, 779, 298, 11, 42, "Text",
      CellTags->"b:0.4"],
    Cell[23503, 794, 108, 3, 29, "Input",
      CellTags->"b:0.4"],
    Cell[23614, 799, 103, 3, 27, "Output",
      CellTags->"b:0.4"],
    Cell[23732, 805, 243, 9, 25, "Text",
      CellTags->"b:0.4"],
    Cell[24000, 818, 174, 4, 49, "Input",
      CellTags->"b:0.4"],
    Cell[24177, 824, 99, 3, 27, "Output",
      CellTags->"b:0.4"],
    Cell[24291, 830, 376, 9, 42, "Text",
      CellTags->"b:0.4"],
    Cell[24670, 841, 143, 5, 25, "Text",
      CellTags->"b:0.4"],
    Cell[24838, 850, 109, 3, 29, "Input",
      CellTags->"b:0.4"],
    Cell[24950, 855, 107, 3, 27, "Output",
      CellTags->"b:0.4"],
    Cell[25072, 861, 187, 6, 25, "Text",
      CellTags->{"UnitUpdate", "i:6", "b:0.4"}],
    Cell[25284, 871, 97, 3, 29, "Input",
      CellTags->"b:0.4"],
    Cell[25384, 876, 114, 3, 27, "Output",
      CellTags->"b:0.4"],
    Cell[25513, 882, 86, 1, 25, "Text",
      CellTags->"b:0.4"],
    Cell[25624, 887, 161, 4, 49, "Input",
      CellTags->"b:0.4"],
    Cell[25788, 893, 114, 3, 27, "Output",
      CellTags->"b:0.4"],
    Cell[25917, 899, 247, 11, 25, "Text",
      CellTags->"b:0.4"],
    Cell[26189, 914, 163, 4, 49, "Input",
      CellTags->"b:0.4"],
    Cell[26355, 920, 99, 3, 27, "Output",
      CellTags->"b:0.4"],
    Cell[26469, 926, 127, 4, 25, "Text",
      CellTags->"b:0.4"],
    Cell[26621, 934, 182, 5, 49, "Input",
      CellTags->"b:0.4"],
    Cell[26806, 941, 108, 3, 27, "Output",
      CellTags->"b:0.4"],
    Cell[26929, 947, 281, 8, 42, "Text",
      CellTags->"b:0.4"],
    Cell[27235, 959, 112, 3, 29, "Input",
      CellTags->"b:0.4"],
    Cell[27350, 964, 103, 3, 27, "Output",
      CellTags->"b:0.4"],
    Cell[27468, 970, 111, 5, 25, "Text",
      CellTags->"b:0.4"],
    Cell[27582, 977, 90, 3, 29, "Input",
      CellTags->"b:0.4"]},
  "c:6"->{
    Cell[22001, 725, 117, 1, 65, "Section",
      CellTags->{"$UnitFormat", "i:5", "b:0.4", "c:6"}]},
  "UnitUpdate"->{
    Cell[25072, 861, 187, 6, 25, "Text",
      CellTags->{"UnitUpdate", "i:6", "b:0.4"}]},
  "i:6"->{
    Cell[25072, 861, 187, 6, 25, "Text",
      CellTags->{"UnitUpdate", "i:6", "b:0.4"}]},
  "b:0.5"->{
    Cell[27709, 985, 82, 1, 65, "Section",
      CellTags->{"b:0.5", "c:7"}],
    Cell[27794, 988, 210, 5, 42, "Text",
      CellTags->"b:0.5"],
    Cell[28029, 997, 162, 4, 49, "Input",
      CellTags->"b:0.5"],
    Cell[28194, 1003, 96, 3, 27, "Output",
      CellTags->"b:0.5"],
    Cell[28305, 1009, 209, 7, 25, "Text",
      CellTags->"b:0.5"],
    Cell[28539, 1020, 94, 3, 29, "Input",
      CellTags->"b:0.5"],
    Cell[28636, 1025, 96, 3, 27, "Output",
      CellTags->"b:0.5"],
    Cell[28747, 1031, 397, 9, 59, "Text",
      CellTags->"b:0.5"],
    Cell[29169, 1044, 155, 4, 49, "Input",
      CellTags->"b:0.5"],
    Cell[29327, 1050, 126, 3, 43, "Output",
      CellTags->"b:0.5"],
    Cell[29468, 1056, 162, 7, 25, "Text",
      CellTags->"b:0.5"],
    Cell[29655, 1067, 80, 3, 29, "Input",
      CellTags->"b:0.5"],
    Cell[29738, 1072, 96, 3, 27, "Output",
      CellTags->"b:0.5"],
    Cell[29849, 1078, 108, 3, 25, "Text",
      CellTags->"b:0.5"],
    Cell[29982, 1085, 130, 3, 29, "Input",
      CellTags->"b:0.5"],
    Cell[30115, 1090, 123, 3, 40, "Output",
      CellTags->"b:0.5"],
    Cell[30253, 1096, 55, 1, 25, "Text",
      CellTags->"b:0.5"],
    Cell[30333, 1101, 101, 3, 29, "Input",
      CellTags->"b:0.5"],
    Cell[30437, 1106, 137, 3, 41, "Output",
      CellTags->"b:0.5"],
    Cell[30589, 1112, 165, 4, 25, "Text",
      CellTags->"b:0.5"],
    Cell[30779, 1120, 166, 4, 49, "Input",
      CellTags->"b:0.5"],
    Cell[30948, 1126, 129, 3, 40, "Output",
      CellTags->"b:0.5"],
    Cell[31092, 1132, 156, 5, 25, "Text",
      CellTags->"b:0.5"],
    Cell[31273, 1141, 116, 3, 40, "Input",
      CellTags->"b:0.5"],
    Cell[31392, 1146, 125, 3, 40, "Output",
      CellTags->"b:0.5"],
    Cell[31532, 1152, 175, 5, 25, "Text",
      CellTags->"b:0.5"],
    Cell[31732, 1161, 129, 3, 29, "Input",
      CellTags->"b:0.5"],
    Cell[31864, 1166, 6242, 119, 919, "Output",
      CellTags->"b:0.5"],
    Cell[38121, 1288, 65, 1, 25, "Text",
      CellTags->"b:0.5"],
    Cell[38189, 1291, 110, 3, 29, "Input",
      CellTags->"b:0.5"]},
  "c:7"->{
    Cell[27709, 985, 82, 1, 65, "Section",
      CellTags->{"b:0.5", "c:7"}]},
  "UnitFormat"->{
    Cell[38336, 1299, 105, 1, 65, "Section",
      CellTags->{"UnitFormat", "i:7", "b:0.6", "c:8"}]},
  "i:7"->{
    Cell[38336, 1299, 105, 1, 65, "Section",
      CellTags->{"UnitFormat", "i:7", "b:0.6", "c:8"}]},
  "b:0.6"->{
    Cell[38336, 1299, 105, 1, 65, "Section",
      CellTags->{"UnitFormat", "i:7", "b:0.6", "c:8"}],
    Cell[38444, 1302, 565, 12, 76, "Text",
      CellTags->"b:0.6"],
    Cell[39012, 1316, 350, 11, 42, "Text",
      CellTags->"b:0.6"],
    Cell[39387, 1331, 127, 3, 29, "Input",
      CellTags->"b:0.6"],
    Cell[39517, 1336, 152, 4, 27, "Output",
      CellTags->"b:0.6"],
    Cell[39684, 1343, 360, 12, 42, "Text",
      CellTags->"b:0.6"],
    Cell[40047, 1357, 80, 1, 25, "Text",
      CellTags->"b:0.6"],
    Cell[40130, 1360, 564, 11, 112, "Input",
      CellTags->"b:0.6"],
    Cell[40697, 1373, 381, 15, 42, "Text",
      CellTags->"b:0.6"],
    Cell[41103, 1392, 242, 5, 69, "Input",
      CellTags->"b:0.6"],
    Cell[41348, 1399, 121, 3, 40, "Output",
      CellTags->"b:0.6"]},
  "c:8"->{
    Cell[38336, 1299, 105, 1, 65, "Section",
      CellTags->{"UnitFormat", "i:7", "b:0.6", "c:8"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 42955, 1437},
  {"Unit`", 43034, 1440},
  {"i:1", 43138, 1443},
  {"b:0.0", 43244, 1446},
  {"c:2", 43416, 1451},
  {"Unit: Introduction", 43535, 1454},
  {"i:2", 43652, 1457},
  {"b:0.1", 43771, 1460},
  {"c:3", 45416, 1509},
  {"Unit: Product", 45543, 1512},
  {"i:3", 45656, 1515},
  {"b:0.2", 45771, 1518},
  {"c:4", 46484, 1539},
  {"Unit: Remove", 46606, 1542},
  {"i:4", 46719, 1545},
  {"b:0.3", 46834, 1548},
  {"c:5", 47868, 1578},
  {"$UnitFormat", 47989, 1581},
  {"i:5", 48102, 1584},
  {"b:0.4", 48217, 1587},
  {"c:6", 50591, 1656},
  {"UnitUpdate", 50711, 1659},
  {"i:6", 50813, 1662},
  {"b:0.5", 50917, 1665},
  {"c:7", 53002, 1726},
  {"UnitFormat", 53099, 1729},
  {"i:7", 53212, 1732},
  {"b:0.6", 53327, 1735},
  {"c:8", 54132, 1758}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 49, 1, 92, "Chapter",
  CellTags->"c:1"],
Cell[1828, 56, 78, 1, 25, "Text"],

Cell[CellGroupData[{
Cell[1931, 61, 72, 1, 65, "Section",
  CellTags->{"Unit`", "i:1", "b:0.0", "c:2"}],
Cell[2006, 64, 1193, 29, 234, "Text",
  CellTags->"b:0.0"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3236, 98, 90, 1, 65, "Section",
  CellTags->{"Unit: Introduction", "i:2", "b:0.1", "c:3"}],
Cell[3329, 101, 272, 7, 42, "Text",
  CellTags->"b:0.1"],
Cell[3604, 110, 57, 1, 25, "Text",
  CellTags->"b:0.1"],
Cell[3664, 113, 88, 3, 29, "Input",
  CellTags->"b:0.1"],
Cell[3755, 118, 154, 5, 25, "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{
Cell[3934, 127, 89, 3, 29, "Input",
  CellTags->"b:0.1"],
Cell[4026, 132, 99, 3, 27, "Output",
  CellTags->"b:0.1"]
}, Open  ]],
Cell[4140, 138, 87, 1, 25, "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{
Cell[4252, 143, 91, 3, 29, "Input",
  CellTags->"b:0.1"],
Cell[4346, 148, 242, 8, 41, "Output",
  CellTags->"b:0.1"]
}, Open  ]],
Cell[4603, 159, 303, 8, 25, "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{
Cell[4931, 171, 94, 3, 29, "Input",
  CellTags->"b:0.1"],
Cell[5028, 176, 95, 3, 27, "Output",
  CellTags->"b:0.1"]
}, Open  ]],
Cell[5138, 182, 142, 5, 25, "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{
Cell[5305, 191, 92, 3, 29, "Input",
  CellTags->"b:0.1"],
Cell[5400, 196, 83, 2, 43, "Output",
  CellTags->"b:0.1"]
}, Open  ]],
Cell[5498, 201, 171, 4, 25, "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{
Cell[5694, 209, 154, 4, 49, "Input",
  CellTags->"b:0.1"],
Cell[5851, 215, 407, 12, 53, "Output",
  CellTags->"b:0.1"]
}, Open  ]],
Cell[6273, 230, 254, 7, 42, "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{
Cell[6552, 241, 104, 3, 29, "Input",
  CellTags->"b:0.1"],
Cell[6659, 246, 103, 3, 27, "Output",
  CellTags->"b:0.1"]
}, Open  ]],
Cell[6777, 252, 101, 4, 25, "Text",
  CellTags->"b:0.1"],
Cell[6881, 258, 86, 3, 29, "Input",
  CellTags->"b:0.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7004, 266, 99, 1, 65, "Section",
  CellTags->{"Unit: Product", "i:3", "b:0.2", "c:4"}],
Cell[7106, 269, 125, 4, 25, "Text",
  CellTags->"b:0.2"],

Cell[CellGroupData[{
Cell[7256, 277, 109, 3, 29, "Input",
  CellTags->"b:0.2"],
Cell[7368, 282, 104, 3, 27, "Output",
  CellTags->"b:0.2"]
}, Open  ]],
Cell[7487, 288, 112, 3, 25, "Text",
  CellTags->"b:0.2"],

Cell[CellGroupData[{
Cell[7624, 295, 137, 3, 29, "Input",
  CellTags->"b:0.2"],
Cell[7764, 300, 113, 3, 27, "Output",
  CellTags->"b:0.2"]
}, Open  ]],
Cell[7892, 306, 75, 1, 25, "Text",
  CellTags->"b:0.2"],

Cell[CellGroupData[{
Cell[7992, 311, 93, 3, 29, "Input",
  CellTags->"b:0.2"],
Cell[8088, 316, 96, 2, 43, "Output",
  CellTags->"b:0.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8233, 324, 103, 1, 65, "Section",
  CellTags->{"Unit: Remove", "i:4", "b:0.3", "c:5"}],
Cell[8339, 327, 207, 7, 25, "Text",
  CellTags->"b:0.3"],

Cell[CellGroupData[{
Cell[8571, 338, 128, 3, 29, "Input",
  CellTags->"b:0.3"],
Cell[8702, 343, 88, 3, 27, "Output",
  CellTags->"b:0.3"]
}, Open  ]],
Cell[8805, 349, 117, 4, 25, "Text",
  CellTags->"b:0.3"],

Cell[CellGroupData[{
Cell[8947, 357, 93, 3, 29, "Input",
  CellTags->"b:0.3"],
Cell[9043, 362, 82, 2, 43, "Output",
  CellTags->"b:0.3"]
}, Open  ]],
Cell[9140, 367, 96, 1, 25, "Text",
  CellTags->"b:0.3"],

Cell[CellGroupData[{
Cell[9261, 372, 285, 6, 29, "Input",
  CellTags->"b:0.3"],
Cell[9549, 380, 104, 3, 27, "Output",
  CellTags->"b:0.3"]
}, Open  ]],
Cell[9668, 386, 90, 1, 25, "Text",
  CellTags->"b:0.3"],

Cell[CellGroupData[{
Cell[9783, 391, 127, 3, 29, "Input",
  CellTags->"b:0.3"],
Cell[9913, 396, 11860, 316, 184, 2732, 197, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"b:0.3"],
Cell[21776, 714, 176, 5, 27, "Output",
  CellTags->"b:0.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22001, 725, 117, 1, 65, "Section",
  CellTags->{"$UnitFormat", "i:5", "b:0.4", "c:6"}],
Cell[22121, 728, 207, 7, 25, "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{
Cell[22353, 739, 90, 3, 29, "Input",
  CellTags->"b:0.4"],
Cell[22446, 744, 94, 3, 27, "Output",
  CellTags->"b:0.4"]
}, Open  ]],
Cell[22555, 750, 287, 13, 25, "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{
Cell[22867, 767, 127, 3, 29, "Input",
  CellTags->"b:0.4"],
Cell[22997, 772, 168, 4, 27, "Output",
  CellTags->"b:0.4"]
}, Open  ]],
Cell[23180, 779, 298, 11, 42, "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{
Cell[23503, 794, 108, 3, 29, "Input",
  CellTags->"b:0.4"],
Cell[23614, 799, 103, 3, 27, "Output",
  CellTags->"b:0.4"]
}, Open  ]],
Cell[23732, 805, 243, 9, 25, "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{
Cell[24000, 818, 174, 4, 49, "Input",
  CellTags->"b:0.4"],
Cell[24177, 824, 99, 3, 27, "Output",
  CellTags->"b:0.4"]
}, Open  ]],
Cell[24291, 830, 376, 9, 42, "Text",
  CellTags->"b:0.4"],
Cell[24670, 841, 143, 5, 25, "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{
Cell[24838, 850, 109, 3, 29, "Input",
  CellTags->"b:0.4"],
Cell[24950, 855, 107, 3, 27, "Output",
  CellTags->"b:0.4"]
}, Open  ]],
Cell[25072, 861, 187, 6, 25, "Text",
  CellTags->{"UnitUpdate", "i:6", "b:0.4"}],

Cell[CellGroupData[{
Cell[25284, 871, 97, 3, 29, "Input",
  CellTags->"b:0.4"],
Cell[25384, 876, 114, 3, 27, "Output",
  CellTags->"b:0.4"]
}, Open  ]],
Cell[25513, 882, 86, 1, 25, "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{
Cell[25624, 887, 161, 4, 49, "Input",
  CellTags->"b:0.4"],
Cell[25788, 893, 114, 3, 27, "Output",
  CellTags->"b:0.4"]
}, Open  ]],
Cell[25917, 899, 247, 11, 25, "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{
Cell[26189, 914, 163, 4, 49, "Input",
  CellTags->"b:0.4"],
Cell[26355, 920, 99, 3, 27, "Output",
  CellTags->"b:0.4"]
}, Open  ]],
Cell[26469, 926, 127, 4, 25, "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{
Cell[26621, 934, 182, 5, 49, "Input",
  CellTags->"b:0.4"],
Cell[26806, 941, 108, 3, 27, "Output",
  CellTags->"b:0.4"]
}, Open  ]],
Cell[26929, 947, 281, 8, 42, "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{
Cell[27235, 959, 112, 3, 29, "Input",
  CellTags->"b:0.4"],
Cell[27350, 964, 103, 3, 27, "Output",
  CellTags->"b:0.4"]
}, Open  ]],
Cell[27468, 970, 111, 5, 25, "Text",
  CellTags->"b:0.4"],
Cell[27582, 977, 90, 3, 29, "Input",
  CellTags->"b:0.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27709, 985, 82, 1, 65, "Section",
  CellTags->{"b:0.5", "c:7"}],
Cell[27794, 988, 210, 5, 42, "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{
Cell[28029, 997, 162, 4, 49, "Input",
  CellTags->"b:0.5"],
Cell[28194, 1003, 96, 3, 27, "Output",
  CellTags->"b:0.5"]
}, Open  ]],
Cell[28305, 1009, 209, 7, 25, "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{
Cell[28539, 1020, 94, 3, 29, "Input",
  CellTags->"b:0.5"],
Cell[28636, 1025, 96, 3, 27, "Output",
  CellTags->"b:0.5"]
}, Open  ]],
Cell[28747, 1031, 397, 9, 59, "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{
Cell[29169, 1044, 155, 4, 49, "Input",
  CellTags->"b:0.5"],
Cell[29327, 1050, 126, 3, 43, "Output",
  CellTags->"b:0.5"]
}, Open  ]],
Cell[29468, 1056, 162, 7, 25, "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{
Cell[29655, 1067, 80, 3, 29, "Input",
  CellTags->"b:0.5"],
Cell[29738, 1072, 96, 3, 27, "Output",
  CellTags->"b:0.5"]
}, Open  ]],
Cell[29849, 1078, 108, 3, 25, "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{
Cell[29982, 1085, 130, 3, 29, "Input",
  CellTags->"b:0.5"],
Cell[30115, 1090, 123, 3, 40, "Output",
  CellTags->"b:0.5"]
}, Open  ]],
Cell[30253, 1096, 55, 1, 25, "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{
Cell[30333, 1101, 101, 3, 29, "Input",
  CellTags->"b:0.5"],
Cell[30437, 1106, 137, 3, 41, "Output",
  CellTags->"b:0.5"]
}, Open  ]],
Cell[30589, 1112, 165, 4, 25, "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{
Cell[30779, 1120, 166, 4, 49, "Input",
  CellTags->"b:0.5"],
Cell[30948, 1126, 129, 3, 40, "Output",
  CellTags->"b:0.5"]
}, Open  ]],
Cell[31092, 1132, 156, 5, 25, "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{
Cell[31273, 1141, 116, 3, 40, "Input",
  CellTags->"b:0.5"],
Cell[31392, 1146, 125, 3, 40, "Output",
  CellTags->"b:0.5"]
}, Open  ]],
Cell[31532, 1152, 175, 5, 25, "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{
Cell[31732, 1161, 129, 3, 29, "Input",
  CellTags->"b:0.5"],
Cell[31864, 1166, 6242, 119, 919, "Output",
  CellTags->"b:0.5"]
}, Open  ]],
Cell[38121, 1288, 65, 1, 25, "Text",
  CellTags->"b:0.5"],
Cell[38189, 1291, 110, 3, 29, "Input",
  CellTags->"b:0.5"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38336, 1299, 105, 1, 65, "Section",
  CellTags->{"UnitFormat", "i:7", "b:0.6", "c:8"}],
Cell[38444, 1302, 565, 12, 76, "Text",
  CellTags->"b:0.6"],
Cell[39012, 1316, 350, 11, 42, "Text",
  CellTags->"b:0.6"],

Cell[CellGroupData[{
Cell[39387, 1331, 127, 3, 29, "Input",
  CellTags->"b:0.6"],
Cell[39517, 1336, 152, 4, 27, "Output",
  CellTags->"b:0.6"]
}, Open  ]],
Cell[39684, 1343, 360, 12, 42, "Text",
  CellTags->"b:0.6"],
Cell[40047, 1357, 80, 1, 25, "Text",
  CellTags->"b:0.6"],
Cell[40130, 1360, 564, 11, 112, "Input",
  CellTags->"b:0.6"],
Cell[40697, 1373, 381, 15, 42, "Text",
  CellTags->"b:0.6"],

Cell[CellGroupData[{
Cell[41103, 1392, 242, 5, 69, "Input",
  CellTags->"b:0.6"],
Cell[41348, 1399, 121, 3, 40, "Output",
  CellTags->"b:0.6"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

