(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     23126,        568]*)
(*NotebookOutlinePosition[     23824,        592]*)
(*  CellTagsIndexPosition[     23780,        588]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Unit`", "Title",
  TextAlignment->Center],

Cell[TextData[{
  "The package ",
  StyleBox["Unit`", "MR"],
  " grants an elegant method to work with units. It uses the definition of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " standard packages ",
  StyleBox["Miscellaneous`Units`", "MR"],
  " , ",
  StyleBox["Miscellaneous`SIUnits`", "MR"],
  ", and ",
  StyleBox["Miscellaneous`PhysicalConstants`", "MR"],
  " and expands its definitions to give:\n1. Compact typing and reading of \
units ",
  StyleBox["5\[SmallCircle]kg", "MR"],
  "\n2. Unit transformation rules ",
  Cell[BoxData[
      \(\(\((2\[SmallCircle]kg)\)\^2\) 
        3\[SmallCircle]m\[LongRightArrow]12\[SmallCircle]kg\^2\ m\)], "MR"],
  "\n3. Subscripts might be used as symbols ",
  Cell[BoxData[
      \(TraditionalForm\`1\[SmallCircle]N\_A\)], "MR"],
  " \n4. Work with fundamental constants as with units\n5. Evaluation \
protection of units, so unit m in expression ",
  StyleBox["m=1; length=1\[SmallCircle]m", "MR"],
  " is treated correctly\n6. The results are presented in globally defined \
format which can be easily changed\n7. The ability of incorporation a set of \
notation for units of specific field of research"
}], "Text"],

Cell["\<\
License
The program is distributed AS IS and its author is not liable for any data \
loss, damages, loss of profits or any other kind of loss while using or \
misusing this software. You may use this product freely for personal \
purposes. You may not use this software with commercial purposes, i.e. get \
any profit from its use, without prior consent of the author. You may copy \
and/or distribute this product without any restrictions, provided that the \
product is not modified.\
\>", "Text"],

Cell["\[Copyright] Yuri E. Kandrashkin, 2007", "Text",
  TextAlignment->Right],

Cell[CellGroupData[{

Cell["Reference", "Section",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Name", "Subsection",
  InitializationCell->True],

Cell[BoxData[
    \( (*\ \(:\)\(Name : \ \ Unit`\)\ *) \)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary", "Subsection",
  InitializationCell->True],

Cell[TextData[{
  "(*\n",
  "The package ",
  StyleBox["Unit`", "MR"],
  " grants an elegant method to work with units. It uses the definition of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " standard packages ",
  StyleBox["Miscellaneous`Units`", "MR"],
  " , ",
  StyleBox["Miscellaneous`SIUnits`", "MR"],
  ", and ",
  StyleBox["Miscellaneous`PhysicalConstants`", "MR"],
  " and expands its definitions to give:\n1. Compact typing and reading of \
units ",
  StyleBox["5\[SmallCircle]kg", "MR"],
  "\n2. Unit transformation rules ",
  Cell[BoxData[
      \(\(\((2\[SmallCircle]kg)\)\^2\) 
        3\[SmallCircle]m\[LongRightArrow]12\[SmallCircle]kg\^2\ m\)], "MR"],
  "\n3. Subscripts might be used as symbols ",
  Cell[BoxData[
      \(TraditionalForm\`1\[SmallCircle]N\_A\)]],
  " \n4. Work with fundamental constants as with units\n5. Evaluation \
protection of units, so unit m in expression ",
  StyleBox["m=1; length=1\[SmallCircle]m", "MR"],
  " is treated correctly\n6. The results are presented in globally defined \
format which can be easily changed\n7. The ability of incorporation a set of \
notation for units of specific field of research",
  "\n*)"
}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Copyright", "Subsection",
  InitializationCell->True],

Cell["(* :Copyright: 2007 by Yuri E. Kandrashkin *)", "Input",
  InitializationCell->True],

Cell["(* http://SpinAlgebra.com *)", "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["License", "Subsection"],

Cell[BoxData[
    \( (*\ License\ *) \)], "Input",
  InitializationCell->True],

Cell["\<\
(*
The program is distributed AS IS and its author is not liable for any data \
loss, damages, loss of profits or any other kind of loss while using or \
misusing this software. You may use this product freely for personal \
purposes. You may not use this software with commercial purposes, i.e. get \
any profit from its use, without prior consent of the author. You may copy \
and or distribute this product without any restrictions, provided that the \
product is not modified.
*)\
\>", "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["History", "Subsection",
  InitializationCell->True],

Cell["(* :History: *)", "Input",
  InitializationCell->True],

Cell["Unit`Private`$Version = \"Version 1.0   Apr 2, 2007\"", "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["$UnitFormat & UnitFormat", "Section",
  InitializationCell->True],

Cell[BoxData[
    \(Scan[
      Needs, {"\<Miscellaneous`Units`\>", "\<Miscellaneous`PhysicalConstants`\
\>"}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(Unit`UnitFormat["\<SI\>"] := SI\), "\[IndentingNewLine]", 
    \(Unit`UnitFormat["\<MKS\>"] := MKS\), "\[IndentingNewLine]", 
    \(Unit`UnitFormat["\<CGS\>"] := CGS\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Unit`UnitFormat["\<SIAcronym\>"] := \[IndentingNewLine]{{HoldPattern[
              A] \[Rule] Ampere, HoldPattern[Bq] \[Rule] Becquerel, 
          HoldPattern[cd] \[Rule] Candela, HoldPattern[C] \[Rule] Coulomb, 
          HoldPattern[F] \[Rule] Farad, HoldPattern[H] \[Rule] Henry, 
          HoldPattern[Hz] \[Rule] Hertz, HoldPattern[J] \[Rule] Joule, 
          HoldPattern[K] \[Rule] Kelvin, HoldPattern[kg] \[Rule] Kilogram, 
          HoldPattern[lm] \[Rule] Lumen, HoldPattern[lx] \[Rule] Lux, 
          HoldPattern[m] \[Rule] Meter, HoldPattern[mol] \[Rule] Mole, 
          HoldPattern[N] \[Rule] Newton, 
          HoldPattern[\[CapitalOmega]] \[Rule] Ohm, 
          HoldPattern[Pa] \[Rule] Pascal, HoldPattern[rad] \[Rule] Radian, 
          HoldPattern[s] \[Rule] Second, HoldPattern[S] \[Rule] Siemens, 
          HoldPattern[T] \[Rule] Tesla, HoldPattern[V] \[Rule] Volt, 
          HoldPattern[W] \[Rule] Watt, 
          HoldPattern[Wb] \[Rule] 
            Weber}, \[IndentingNewLine]{Ampere \[RuleDelayed] A, 
          Becquerel \[RuleDelayed] Bq, Candela \[RuleDelayed] cd, 
          Coulomb \[RuleDelayed] C, Farad \[RuleDelayed] F, 
          Henry \[RuleDelayed] H, Hertz \[RuleDelayed] Hz, 
          Joule \[RuleDelayed] J, Kelvin \[RuleDelayed] K, 
          Kilogram \[RuleDelayed] kg, Lumen \[RuleDelayed] lm, 
          Lux \[RuleDelayed] lx, Meter \[RuleDelayed] m, 
          Mole \[RuleDelayed] mol, Newton \[RuleDelayed] N, 
          Ohm \[RuleDelayed] \[CapitalOmega], Pascal \[RuleDelayed] Pa, 
          Radian \[RuleDelayed] rad, Second \[RuleDelayed] s, 
          Siemens \[RuleDelayed] S, Tesla \[RuleDelayed] T, 
          Volt \[RuleDelayed] V, Watt \[RuleDelayed] W, 
          Weber \[RuleDelayed] Wb}}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{\(Unit`UnitFormat["\<SIConstants\>"]\), ":=", 
      "\[IndentingNewLine]", 
      RowBox[{"Join", "@@@", 
        RowBox[{"Transpose", "[", 
          RowBox[{"{", "\[IndentingNewLine]", 
            
            RowBox[{\(Unit`UnitFormat["\<SIAcronym\>"]\), ",", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"{", 
                    
                    RowBox[{\(HoldPattern[c] \[Rule] SpeedOfLight\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[\[Mu]\_0] \[Rule] 
                        VacuumPermeability\), ",", 
                      "\[IndentingNewLine]", \
\(HoldPattern[\[CurlyEpsilon]\_0] \[Rule] VacuumPermittivity\), ",", 
                      "\[IndentingNewLine]", 
                      RowBox[{\(HoldPattern[\[HBar]]\), "\[Rule]", 
                        StyleBox["PlanckConstantReduced",
                          GridBoxOptions->{RowSpacings->0.4,
                          RowLines->False}]}], 
                      StyleBox[",",
                        GridBoxOptions->{RowSpacings->0.4,
                        RowLines->False}], 
                      StyleBox["\[IndentingNewLine]",
                        GridBoxOptions->{RowSpacings->0.4,
                        RowLines->False}], \(HoldPattern[e] \[Rule] 
                        ElectronCharge\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[m\_e] \[Rule] 
                        ElectronMass\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[m\_p] \[Rule] 
                        ProtonMass\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[m\_n] \[Rule] 
                        NeutronMass\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[N\_A] \[Rule] 
                        AvogadroConstant\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[k] \[Rule] 
                        BoltzmannConstant\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[F] \[Rule] 
                        FaradayConstant\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[R] \[Rule] 
                        MolarGasConstant\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[\[Alpha]] \[Rule] 
                        FineStructureConstant\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[a\_0] \[Rule] 
                        BohrRadius\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[
                          R\_\[Infinity]] \[Rule] RydbergConstant\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[\[Lambda]\_c] \
\[Rule] ElectronComptonWavelength\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[\[Mu]\_B] \[Rule] 
                        ElectronCharge\ PlanckConstantReduced/\((2  
                                ElectronMass)\)\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[\[Mu]\_e] \[Rule] 
                        ElectronMagneticMoment\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[g\_e] \[Rule] 
                        ElectronGFactor\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[\[Mu]\_p] \[Rule] 
                        ProtonMagneticMoment\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[G] \[Rule] 
                        GravitationalConstant\), ",", 
                      "\[IndentingNewLine]", \(HoldPattern[g\_n] \[Rule] 
                        AccelerationDueToGravity\)}], "}"}], ",", 
                  "\[IndentingNewLine]", \({}\)}], "}"}]}], "}"}], 
          "]"}]}]}]], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Unit`UnitFormat["\<SIFundamental\>"] \
:= \[IndentingNewLine]{{HoldPattern[kg] \[RuleDelayed] 
              Kilogram, \[IndentingNewLine]HoldPattern[m] \[RuleDelayed] 
              Meter, \[IndentingNewLine]HoldPattern[s] \[RuleDelayed] 
              Second, \[IndentingNewLine]HoldPattern[K] \[RuleDelayed] 
              Kelvin, \[IndentingNewLine]HoldPattern[A] \[RuleDelayed] 
              Ampere, \[IndentingNewLine]HoldPattern[mol] \[RuleDelayed] 
              Mole, \[IndentingNewLine]HoldPattern[cd] \[RuleDelayed] 
              Candela, \[IndentingNewLine]HoldPattern[rad] \[RuleDelayed] 
              Radian, \[IndentingNewLine]HoldPattern[sr] \[RuleDelayed] 
              Steradian, \[IndentingNewLine]HoldPattern[Hz] \[RuleDelayed] 
              Hertz, \[IndentingNewLine]Hertz \[RuleDelayed] 
              s\^\(-1\), \[IndentingNewLine]HoldPattern[N] \[RuleDelayed] 
              Newton, \[IndentingNewLine]Newton \[RuleDelayed] 
              m\ kg\ s\^\(-2\), \[IndentingNewLine]HoldPattern[
                Pa] \[RuleDelayed] 
              Pascal, \[IndentingNewLine]Pascal \[RuleDelayed] 
              m\^\(-1\)\ kg\ s\^\(-2\), \[IndentingNewLine]HoldPattern[
                J] \[RuleDelayed] 
              Joule, \[IndentingNewLine]Joule \[RuleDelayed] 
              m\^2\ kg\ s\^\(-2\), \[IndentingNewLine]HoldPattern[
                W] \[RuleDelayed] 
              Watt, \[IndentingNewLine]Watt \[RuleDelayed] 
              m\^2\ kg\ s\^\(-3\), \[IndentingNewLine]HoldPattern[
                C] \[RuleDelayed] 
              Coulomb, \[IndentingNewLine]Coulomb \[RuleDelayed] 
              A\ s, \[IndentingNewLine]HoldPattern[V] \[RuleDelayed] 
              Volt, \[IndentingNewLine]Volt \[RuleDelayed] 
              m\^2\ kg\ s\^\(-3\)\ A\^\(-1\), \[IndentingNewLine]HoldPattern[\
\[CapitalOmega]] \[RuleDelayed] Ohm, \[IndentingNewLine]Ohm \[RuleDelayed] 
              m\^2\ \ kg\ s\^\(-3\)\ A\^\(-2\), \
\[IndentingNewLine]HoldPattern[S] \[RuleDelayed] 
              Siemens, \[IndentingNewLine]Siemens \[RuleDelayed] 
              m\^\(-2\)\ \ kg\^\(-1\)\ s\^3\ A\^2, \
\[IndentingNewLine]HoldPattern[F] \[RuleDelayed] 
              Farad, \[IndentingNewLine]Farad \[RuleDelayed] 
              m\^\(-2\)\ \ kg\^\(-1\)\ s\^4\ A\^2, \
\[IndentingNewLine]HoldPattern[Wb] \[RuleDelayed] 
              Weber, \[IndentingNewLine]Weber \[RuleDelayed] 
              
              m\^2\ \ kg\ s\^\(-2\)\ A\^\(-1\), \
\[IndentingNewLine]HoldPattern[T] \[RuleDelayed] 
              Tesla, \[IndentingNewLine]Tesla \[RuleDelayed] 
              kg\ s\^\(-2\)\ A\^\(-1\), \[IndentingNewLine]HoldPattern[
                H] \[RuleDelayed] 
              Henry, \[IndentingNewLine]Henry \[RuleDelayed] 
              m\^2\ \ kg\ s\^\(-2\)\ A\^\(-2\), \
\[IndentingNewLine]HoldPattern[lm] \[RuleDelayed] 
              Lumen, \[IndentingNewLine]Lumen \[RuleDelayed] 
              cd\ sr, \[IndentingNewLine]HoldPattern[lx] \[RuleDelayed] 
              Lux, \[IndentingNewLine]Lux \[RuleDelayed] 
              cd\ sr\ m\^\(-2\), \[IndentingNewLine]HoldPattern[
                Bq] \[RuleDelayed] 
              Becquerel, \[IndentingNewLine]Becquerel \[RuleDelayed] 
              s\^\(-1\)}, \[IndentingNewLine]{Meter \[RuleDelayed] 
              m, \[IndentingNewLine]Kilogram \[RuleDelayed] 
              kg, \[IndentingNewLine]Second \[RuleDelayed] 
              s, \[IndentingNewLine]Kelvin \[RuleDelayed] 
              K, \[IndentingNewLine]Ampere \[RuleDelayed] 
              A, \[IndentingNewLine]Mole \[RuleDelayed] 
              mol, \[IndentingNewLine]Candela \[RuleDelayed] 
              cd, \[IndentingNewLine]Radian \[RuleDelayed] 
              rad, \[IndentingNewLine]Steradian \[RuleDelayed] 
              sr}};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Unit`$UnitFormat = "\<SI\>"\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Package Beginning", "Section",
  InitializationCell->True],

Cell[BoxData[
    \(BeginPackage["\<Unit`\>", {"\<Miscellaneous`Units`\>", \
"\<Miscellaneous`PhysicalConstants`\>"}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(UnitFormat::"\<usage\>" = "\<The argument arg of definition UnitFormat[\
\"format\"]={{inrules},{outrules}} used to set $UnitFormat=\"arg\".\nThe \
rules used to convert input expression in SI units and result of computation \
to \"format\".\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \($UnitFormat::"\<usage\>" = "\<$UnitFormat=\"format\" is a global \
variable of package Unit`.\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Unit::"\<usage\>" = "\<a Unit[kg] \[DoubleLongLeftRightArrow] a\
\[SmallCircle]kg\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(UnitUpdate::"\<usage\>" = "\<UnitUpdate updates the information of \
function Unit according to the value of $UnitFormat\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(SmallCircle::"\<usage\>" = "\<Symbol \"\[SmallCircle]\" used by package \
Unit` to separate the value and units in the expression\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Begin["\<`Private`\>"]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Unit & UnitUpdate", "Section",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Unit", "Subsection",
  InitializationCell->True],

Cell[BoxData[
    \(Unit::"\<fmt\>" = "\<The function UnitFormat for argument `1` is \
undefined.\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(MakeExpression[RowBox[{a__, "\<\[SmallCircle]\>", b_}], form_] := 
      MakeExpression[RowBox[{a, "\<Unit\>", "\<[\>", b, "\<]\>"}], 
        form]\), "\[IndentingNewLine]", 
    \(\(MakeExpression[SmallCircle[a_, b_], form_] := 
        MakeExpression[RowBox[{a, "\<Unit\>", "\<[\>", b, "\<]\>"}], 
          form];\)\), "\[IndentingNewLine]", 
    \(\(MakeBoxes[Times[a___, Unit[b_], c___], form_] := 
        RowBox[{ToBoxes[Times[a, c], form], "\<\[SmallCircle]\>", 
            MakeBoxes[b, form]}];\)\), "\[IndentingNewLine]", 
    \(\(MakeBoxes[Unit[b_], form_] := 
        RowBox[{"\<1\>", "\<\[SmallCircle]\>", 
            MakeBoxes[b, form]}];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(SetAttributes[Unit, {HoldAll}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(Unit /: a___\ Unit[b_] c___\ Unit[d_]\ e___ := 
      a\ c\ e\ unit[b\ d]\), "\[IndentingNewLine]", 
    \(Unit /: Unit[a_]\^n_ := unit[a\^n]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(SetAttributes[{unit, holdUnit}, {HoldAll}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(unit[
        a_] := \[IndentingNewLine]Module[{$outFormat, $inFormat, inRules, 
          outRules, rulesQ, expr, formalVars}, \[IndentingNewLine]$inFormat = 
          Switch[$UnitFormat, _List, $UnitFormat, _, {$UnitFormat}]; \
\[IndentingNewLine]$outFormat = First@$inFormat; \[IndentingNewLine]If[
          MatchQ[$inFormat, {_, All}], $inFormat = \(Part[#, 1, 1, 1] &\) /@ 
              DownValues[UnitFormat]]; \[IndentingNewLine]inRules = 
          First /@ Cases[
              UnitFormat /@ $inFormat, {{___}, {___}}, {1}]; \
\[IndentingNewLine]outRules = 
          UnitFormat[$outFormat]; \[IndentingNewLine]rulesQ = 
          MatchQ[outRules, {{___}, {___}}]; \[IndentingNewLine]If[rulesQ, 
          outRules = Last@outRules]; \[IndentingNewLine]expr = 
          holdUnit[a]; \[IndentingNewLine]expr = 
          Fold[replaceAllButSubscript[ReplaceRepeated, ##] &, expr, 
            inRules]; \[IndentingNewLine]formalVars = 
          If[rulesQ, Append[expr, outRules], 
            expr]; \[IndentingNewLine]formalVars = 
          Union[DeleteCases[
              formalVars //. 
                holdUnit[x___, _[y___], z___] \[RuleDelayed] 
                  holdUnit[x, y, z], _?
                  NumberQ | _String, \[Infinity]]]; \[IndentingNewLine]Apply[
          Block, formalVars /. 
            holdUnit[
                x__] \[RuleDelayed] \[IndentingNewLine]holdUnit[{Unit, 
                  Subscript, x}, \[IndentingNewLine]expr = 
                  Unit[Times @@ expr]; \[IndentingNewLine]expr = 
                  If[rulesQ, \[IndentingNewLine]replaceAllButSubscript[
                      ReplaceRepeated, expr, outRules], \[IndentingNewLine]If[
                      Head[outRules] =!= 
                        UnitFormat, \[IndentingNewLine]outRules[
                        expr], \[IndentingNewLine]Message[Unit::"\<fmt\>", 
                        InputForm[$UnitFormat]]]]; \
\[IndentingNewLine]\(\(expr //. 
                      Unit[Times[y_?NumberQ, z__]] \[RuleDelayed] 
                        y\ Unit[Times[z]]\) /. \[IndentingNewLine]Unit[
                        Times[z_]] \[RuleDelayed] 
                      Unit[z]\) /. {Unit[z_?NumberQ] \[RuleDelayed] z, 
                    Unit[] \[Rule] 1}]]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(replaceAllButSubscript[h : \((ReplaceAll | ReplaceRepeated)\), expr_, 
        rules_] := \[IndentingNewLine]Block[{Subscript, 
          Message}, \[IndentingNewLine]SetAttributes[Subscript, 
          HoldAll]; \[IndentingNewLine]Module[{rul1, rul2, 
            x}, \[IndentingNewLine]Remove["\<Unit`Private`xxx*\>"]; \
\[IndentingNewLine]rul1 = \(rul2 = {}\); \[IndentingNewLine]\(\((x = 
                  Unique["\<Unit`Private`xxx\>"]; 
                AppendTo[rul1, # \[Rule] x]; 
                AppendTo[rul2, 
                  x \[Rule] \ #])\) &\) /@ \[IndentingNewLine]Cases[{expr, 
                rules}, _Subscript, \[Infinity]]; \[IndentingNewLine]h[
              expr /. rul1, rules /. rul1] /. rul2]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["UnitUpdate", "Subsection",
  InitializationCell->True],

Cell[BoxData[{
    \(UnitUpdate[expr_] := 
      expr /. Unit[a_] \[RuleDelayed] unit[a]\), "\[IndentingNewLine]", 
    \(UnitUpdate[expr_, form_] := 
      Block[{$UnitFormat = form}, 
        expr /. Unit[a_] \[RuleDelayed] unit[a]]\)}], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["End", "Section",
  InitializationCell->True],

Cell[BoxData[{
    \(End[]\), "\[IndentingNewLine]", 
    \(EndPackage[]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(SetAttributes[{Unit, UnitUpdate}, {ReadProtected, 
        Protected}]\), "\[IndentingNewLine]", 
    \(SetAttributes[{UnitFormat}, {Protected}]\)}], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 781}},
AutoGeneratedPackage->Automatic,
WindowSize->{979, 740},
WindowMargins->{{Automatic, 30}, {0, Automatic}},
ShowSelection->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 47, 1, 95, "Title"],
Cell[1826, 56, 1178, 28, 185, "Text"],
Cell[3007, 86, 509, 9, 90, "Text"],
Cell[3519, 97, 78, 1, 33, "Text"],

Cell[CellGroupData[{
Cell[3622, 102, 56, 1, 73, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[3703, 107, 54, 1, 38, "Subsection",
  InitializationCell->True],
Cell[3760, 110, 96, 2, 30, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[3893, 117, 57, 1, 38, "Subsection",
  InitializationCell->True],
Cell[3953, 120, 1221, 31, 210, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[5211, 156, 59, 1, 38, "Subsection",
  InitializationCell->True],
Cell[5273, 159, 90, 1, 30, "Input",
  InitializationCell->True],
Cell[5366, 162, 73, 1, 30, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[5476, 168, 29, 0, 38, "Subsection"],
Cell[5508, 170, 78, 2, 30, "Input",
  InitializationCell->True],
Cell[5589, 174, 536, 11, 120, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[6162, 190, 57, 1, 38, "Subsection",
  InitializationCell->True],
Cell[6222, 193, 60, 1, 30, "Input",
  InitializationCell->True],
Cell[6285, 196, 98, 1, 30, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6432, 203, 71, 1, 73, "Section",
  InitializationCell->True],
Cell[6506, 206, 151, 4, 30, "Input",
  InitializationCell->True],
Cell[6660, 212, 228, 4, 70, "Input",
  InitializationCell->True],
Cell[6891, 218, 1814, 29, 210, "Input",
  InitializationCell->True],
Cell[8708, 249, 3742, 67, 530, "Input",
  InitializationCell->True],
Cell[12453, 318, 3844, 65, 1033, "Input",
  InitializationCell->True],
Cell[16300, 385, 88, 2, 30, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[16425, 392, 64, 1, 73, "Section",
  InitializationCell->True],
Cell[16492, 395, 158, 3, 30, "Input",
  InitializationCell->True],
Cell[16653, 400, 305, 5, 70, "Input",
  InitializationCell->True],
Cell[16961, 407, 157, 3, 30, "Input",
  InitializationCell->True],
Cell[17121, 412, 145, 3, 30, "Input",
  InitializationCell->True],
Cell[17269, 417, 184, 3, 30, "Input",
  InitializationCell->True],
Cell[17456, 422, 193, 3, 30, "Input",
  InitializationCell->True],
Cell[17652, 427, 83, 2, 30, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[17772, 434, 64, 1, 73, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[17861, 439, 54, 1, 38, "Subsection",
  InitializationCell->True],
Cell[17918, 442, 141, 3, 30, "Input",
  InitializationCell->True],
Cell[18062, 447, 720, 13, 90, "Input",
  InitializationCell->True],
Cell[18785, 462, 91, 2, 30, "Input",
  InitializationCell->True],
Cell[18879, 466, 204, 4, 50, "Input",
  InitializationCell->True],
Cell[19086, 472, 103, 2, 30, "Input",
  InitializationCell->True],
Cell[19192, 476, 2318, 41, 470, "Input",
  InitializationCell->True],
Cell[21513, 519, 783, 13, 190, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[22333, 537, 60, 1, 38, "Subsection",
  InitializationCell->True],
Cell[22396, 540, 276, 6, 50, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22721, 552, 50, 1, 73, "Section",
  InitializationCell->True],
Cell[22774, 555, 114, 3, 50, "Input",
  InitializationCell->True],
Cell[22891, 560, 207, 4, 50, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

